Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\dev\__init__.py: 71%

# Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\dev\__init__.py : 71%

## 28 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# Copyright (c) 2019-2020 ETH Zurich, SIS ID and HVL D-ITET

2#

3"""Devices subpackage."""

4

5 import sys

6

7 from .base import ( # noqa: F401

8 Device,

9 DeviceExistingException,

10 DeviceSequenceMixin,

11 DeviceFailuresException,

12 SingleCommDevice,

13)

14 from .crylas import ( # noqa: F401

15 CryLasLaser,

16 CryLasLaserConfig,

17 CryLasLaserSerialCommunication,

18 CryLasLaserSerialCommunicationConfig,

19 CryLasLaserError,

20 CryLasLaserNotReadyError,

21 CryLasAttenuator,

22 CryLasAttenuatorConfig,

23 CryLasAttenuatorSerialCommunication,

24 CryLasAttenuatorSerialCommunicationConfig,

25 CryLasAttenuatorError,

26)

27 from .ea_psi9000 import ( # noqa: F401

28 PSI9000,

29 PSI9000Config,

30 PSI9000VisaCommunication,

31 PSI9000VisaCommunicationConfig,

32 PSI9000Error,

33)

34 from .fug import ( # noqa: F401

35 FuG,

36 FuGConfig,

37 FuGSerialCommunication,

38 FuGSerialCommunicationConfig,

39 FuGError,

40 FuGErrorcodes,

41 FuGDigitalVal,

42 FuGTerminators,

43 FuGPolarities,

44 FuGReadbackChannels,

45 FuGMonitorModes,

46 FuGRampModes,

47)

48 from .heinzinger import ( # noqa: F401

49 HeinzingerDI,

50 HeinzingerPNC,

51 HeinzingerConfig,

52 HeinzingerPNCError,

53 HeinzingerPNCMaxVoltageExceededException,

54 HeinzingerPNCMaxCurrentExceededException,

55 HeinzingerPNCDeviceNotRecognizedException,

56 HeinzingerSerialCommunication,

57 HeinzingerSerialCommunicationConfig,

58)

59

60 try:

61 from .labjack import ( # noqa: F401

62 LabJack,

63 LabJackError,

64 LabJackIdentifierDIOError,

65 )

66 except (ImportError, ModuleNotFoundError):

67 import warnings

68

69 warnings.warn("To use labjack library install hvl with command "

70 "`pip install hvl_ccb[labjack]`.")

71 from .mbw973 import ( # noqa: F401

72 MBW973,

73 MBW973Config,

74 MBW973ControlRunningException,

75 MBW973PumpRunningException,

76 MBW973Error,

77 MBW973SerialCommunication,

78 MBW973SerialCommunicationConfig,

79)

80 from .newport import ( # noqa: F401

81 NewportSMC100PP,

82 NewportSMC100PPConfig,

83 NewportStates,

84 NewportSMC100PPSerialCommunication,

85 NewportSMC100PPSerialCommunicationConfig,

86 NewportConfigCommands,

87 NewportMotorError,

88 NewportControllerError,

89 NewportSerialCommunicationError,

90 NewportUncertainPositionError,

91 NewportMotorPowerSupplyWasCutError,

92)

93 from .pfeiffer_tpg import ( # noqa: F401

94 PfeifferTPG,

95 PfeifferTPGConfig,

96 PfeifferTPGSerialCommunication,

97 PfeifferTPGSerialCommunicationConfig,

98 PfeifferTPGError,

99)

100 from .rs_rto1024 import ( # noqa: F401

101 RTO1024,

102 RTO1024Error,

103 RTO1024Config,

104 RTO1024VisaCommunication,

105 RTO1024VisaCommunicationConfig,

106)

107 from .se_ils2t import ( # noqa: F401

108 ILS2T,

109 ILS2TConfig,

110 ILS2TException,

111 ILS2TModbusTcpCommunication,

112 ILS2TModbusTcpCommunicationConfig,

113 IoScanningModeValueError,

114 ScalingFactorValueError,

115)

116 from .sst_luminox import ( # noqa: F401

117 Luminox,

118 LuminoxConfig,

119 LuminoxSerialCommunication,

120 LuminoxSerialCommunicationConfig,

121 LuminoxMeasurementType,

122 LuminoxMeasurementTypeError,

123 LuminoxOutputMode,

124 LuminoxOutputModeError,

125)

126 from .technix import ( # noqa: F401

127 Technix,

128 TechnixError,

129 TechnixTelnetCommunication,

130 TechnixSerialCommunication,

131)

132 from .visa import ( # noqa: F401

133 VisaDevice,

134 VisaDeviceConfig,

135)

136

137 if sys.platform == 'darwin':

138 import warnings

139 warnings.warn("libtiepie is not available for Darwin OSs")

140 else:

141 try:

142 from .tiepie import ( # noqa: F401

143 TiePieDeviceConfig,

144 TiePieDeviceType,

145 TiePieError,

146 TiePieGeneratorConfig,

147 TiePieHS5,

148 TiePieHS6,

149 TiePieI2CHostConfig,

150 TiePieOscilloscope,

151 TiePieOscilloscopeChannelCoupling,

152 TiePieOscilloscopeChannelConfig,

153 TiePieOscilloscopeConfig,

154 TiePieOscilloscopeRange,

155 TiePieOscilloscopeResolution,

156 TiePieOscilloscopeTriggerKind,

157 TiePieWS5,

158 TiePieOscilloscopeTriggerLevelMode,

159 TiePieGeneratorSignalType,

160 TiePieOscilloscopeAutoResolutionModes

161 )

162 except (ImportError, ModuleNotFoundError):

163 import warnings

164

165 warnings.warn("To use libtiepie library install hvl with command "

166 "`pip install hvl_ccb[tiepie]`.")